==> haskell-path-io-1.8.2-132-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path-io
version:              1.8.2
visibility:           public
id:                   path-io-1.8.2-Jhknddu9AtCK2EGLcU8uTt
key:                  path-io-1.8.2-Jhknddu9AtCK2EGLcU8uTt
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  2d017cc3b0e6a74169495a58e902fda0
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-9.6.6/site-local/path-io-1.8.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/path-io-1.8.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/path-io-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path-io
hs-libraries:         HSpath-io-1.8.2-Jhknddu9AtCK2EGLcU8uTt
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO exceptions-0.10.7
    filepath-1.4.300.1 path-0.9.6-7b6FXKI3CMdJjRU7VALKqo
    temporary-1.3-DmygwHaZA8GJCfyTYb6Tkl time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.8.2-133-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 path-io
version:              1.8.2
visibility:           public
id:                   path-io-1.8.2-CWPMy5Meh3QEKkmaY17vKO
key:                  path-io-1.8.2-CWPMy5Meh3QEKkmaY17vKO
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  516578b19d8a320b1dd1bdb1966ff7e9
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-9.6.6/site-local/path-io-1.8.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/path-io-1.8.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/path-io-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-path-io
hs-libraries:         HSpath-io-1.8.2-CWPMy5Meh3QEKkmaY17vKO
depends:
    base-4.18.2.1 containers-0.6.7 directory-1.3.8.5
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO exceptions-0.10.7
    filepath-1.4.300.1 path-0.9.6-JZJSfxZgLNX9Y539GdP67P
    temporary-1.3-29RL4tTXoFB72QSCtJnhBC time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
